import os

from setuptools import setup, Command

package_name = 'topmind-s3'
version = '2.0.0'


class CleanCommand(Command):
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        os.system('rm -vrf ./build ./dist ./*.pyc ./*.tgz ./*.egg-info ./.pytest_cache ./.eggs')


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name=package_name,
    packages=[package_name],
    package_dir={
        package_name: 's3'
    },
    version=version,
    license='MIT',
    description='TopMind S3 Helper',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Pavel Popov',
    author_email='p.popov@talenttech.ru',
    url='https://github.com/severgroup-tt/topmind-commons',
    install_requires=[
        'boto3'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    cmdclass={
        'clean': CleanCommand
    },
    setup_requires=['pytest-runner'],
    tests_require=['pytest']
)
